<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ja_JP">
<context>
    <name>QvkAudioController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>一つ以上のデバイスを選択</translation>
    </message>
</context>
<context>
    <name>QvkAudioController_wl</name>
    <message>
        <source>Select one or more devices</source>
        <translation>一つ以上のデバイスを選択</translation>
    </message>
</context>
<context>
    <name>QvkCameraSingle</name>
    <message>
        <source>Remove window frame</source>
        <translation>ウィンドウ枠非表示</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>垂直反転</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>水平反転</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>ネガポジ反転</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>グレー</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>白黒</translation>
    </message>
    <message>
        <source>Switch to Window</source>
        <translation>ウィンドウ表示</translation>
    </message>
    <message>
        <source>Switch to Fullscreen</source>
        <translation>全画面表示</translation>
    </message>
</context>
<context>
    <name>QvkCameraWindow</name>
    <message>
        <source>Camera</source>
        <translation>カメラ</translation>
    </message>
</context>
<context>
    <name>QvkCiscoFinishDialog</name>
    <message>
        <source>The setup was successful.</source>
        <translation>初期設定は完了しました。</translation>
    </message>
    <message>
        <source>Close this window and start vokoscreenNG again.</source>
        <translation>このウィンドウを閉じてvokoscreenNGを再度起動してください。</translation>
    </message>
    <message>
        <source>Have fun with vokoscreenNG</source>
        <translation>vokoscreenNGをお楽しみください</translation>
    </message>
</context>
<context>
    <name>QvkDirDialog</name>
    <message>
        <source>Dialog</source>
        <translation>ダイアログ</translation>
    </message>
</context>
<context>
    <name>QvkHelp</name>
    <message>
        <source>Help</source>
        <translation>ヘルプ</translation>
    </message>
</context>
<context>
    <name>QvkImageFromTabs</name>
    <message>
        <source>No filemanager found.</source>
        <translation>ファイルマネージャーが見つかりません</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>ファイルマネージャーをインストールしてください</translation>
    </message>
</context>
<context>
    <name>QvkImageFromTabs_wl</name>
    <message>
        <source>No filemanager found.</source>
        <translation>ファイルマネージャーが見つかりません</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>ファイルマネージャーをインストールしてください</translation>
    </message>
</context>
<context>
    <name>QvkLimitDiskFreeSpace</name>
    <message>
        <source>Warning</source>
        <translation>警告</translation>
    </message>
    <message>
        <source>The recording is not started, not enough free disk space.</source>
        <translation>録画が開始できません。十分なディスク領域がありません。</translation>
    </message>
    <message>
        <source>The free disk space limit is reached.</source>
        <translation>空きディスク領域が制限に達しました。</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>空きディスク容量の制限</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>メガバイト</translation>
    </message>
    <message>
        <source>The recording was stopped, not enough free disk space.</source>
        <translation>録画を中止しました。ディスク領域が不足しています。</translation>
    </message>
</context>
<context>
    <name>QvkMainWindow</name>
    <message>
        <source>No filemanager found.</source>
        <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
        <translation>ファイルマネージャーが見つかりません</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>ファイルマネージャーをインストールしてください</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>ソースコード</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>ホームページ</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>翻訳</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>寄付</translation>
    </message>
</context>
<context>
    <name>QvkMainWindow_wl</name>
    <message>
        <source>Sourcecode</source>
        <translation>ソースコード</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>ホームページ</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>翻訳</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>寄付</translation>
    </message>
    <message>
        <source>No filemanager found.</source>
        <translation>ファイルマネージャーが見つかりません</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>ファイルマネージャーをインストールしてください</translation>
    </message>
</context>
<context>
    <name>QvkPulseAudioWatcher</name>
    <message>
        <source>Select one or more devices</source>
        <translation>一つ以上のデバイスを選択</translation>
    </message>
</context>
<context>
    <name>QvkPulseAudioWatcher_wl</name>
    <message>
        <source>Select one or more devices</source>
        <translation>一つ以上のデバイスを選択</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise</name>
    <message>
        <source>Area</source>
        <translation>範囲</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise_wl</name>
    <message>
        <source>Area</source>
        <translation>範囲</translation>
    </message>
</context>
<context>
    <name>QvkSnapshot</name>
    <message>
        <source>No filemanager found.</source>
        <translation>ファイルマネージャーが見つかりません</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>ファイルマネージャーをインストールしてください</translation>
    </message>
</context>
<context>
    <name>QvkSystray</name>
    <message>
        <source>Start</source>
        <translation>開始</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>停止</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>一時停止</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>持続する</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>終了する</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>カメラ</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>拡大</translation>
    </message>
</context>
<context>
    <name>QvkSystrayAlternative</name>
    <message>
        <source>Start</source>
        <translation>開始</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>停止</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>一時停止</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>持続する</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>終了する</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>カメラ</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>拡大</translation>
    </message>
</context>
<context>
    <name>QvkWASAPIController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>一つ以上のデバイスを選択</translation>
    </message>
</context>
<context>
    <name>cameraSettingsDialog</name>
    <message>
        <source>Dialog</source>
        <translation>ダイアログ</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>水平反転</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>垂直反転</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>ネガポジ反転</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>グレー</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>白黒</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>ウィンドウ枠非表示</translation>
    </message>
    <message>
        <source>Camera settings</source>
        <translation>カメラの設定</translation>
    </message>
</context>
<context>
    <name>formMainWindow</name>
    <message>
        <source>Area</source>
        <translation>範囲</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>リセット</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>拡大</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>カウントダウン</translation>
    </message>
    <message>
        <source>Video size:</source>
        <translation>動画サイズ</translation>
    </message>
    <message>
        <source>Free disk space:</source>
        <translation>空きディスク領域:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>情報</translation>
    </message>
    <message>
        <source>Record Time:</source>
        <translation>録画時間:</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>オーディオ</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>フレーム</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>動画コーデック</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>形式</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>音声コーデック</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>マウスカーソルを録画しない</translation>
    </message>
    <message>
        <source>Hour</source>
        <translation>時間</translation>
    </message>
    <message>
        <source>Minute</source>
        <translation>分</translation>
    </message>
    <message>
        <source>Start the timer</source>
        <translation>指定時刻に開始</translation>
    </message>
    <message>
        <source>Stop recording after</source>
        <translation>指定時間後に録画終了</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>時</translation>
    </message>
    <message>
        <source>Minutes</source>
        <translation>分</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>秒</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>ビデオ保存パス</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>空きディスク容量の制限</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>システムトレイに表示</translation>
    </message>
    <message>
        <source>Second wait before recording</source>
        <translation>録画前の秒数</translation>
    </message>
    <message>
        <source>Look for updates</source>
        <translation>更新を確認</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>ヘルプ</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>ビデオ</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>利用可能</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>利用不可</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>開始</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>停止</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>一時停止</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>持続する</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>再生</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>フォルダー</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>カメラ</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>ネガポジ反転</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>グレー</translation>
    </message>
    <message>
        <source>Play last record</source>
        <translation>最後の録画を再生する</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>フォルダーを開く</translation>
    </message>
    <message>
        <source>Minimized when recording starts</source>
        <translation>録画開始時に最小化</translation>
    </message>
    <message>
        <source>Starts minimized</source>
        <translation>最小化して開始</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>水平反転</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>垂直反転</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>白黒</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>ウィンドウ枠非表示</translation>
    </message>
    <message>
        <source>Reset all settings at the next start</source>
        <translation>次回起動時にすべての設定をリセットする</translation>
    </message>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>画像の著作権およびライセンス</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>メガバイト</translation>
    </message>
    <message>
        <source>Screencast</source>
        <translation>スクリーンキャスト</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>プレーヤー</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>ログ</translation>
    </message>
    <message>
        <source>Automatically</source>
        <translation>自動的に</translation>
    </message>
    <message>
        <source>Create images of tabs </source>
        <translation>タブのイメージを作成</translation>
    </message>
    <message>
        <source>License information</source>
        <translation>ライセンス情報</translation>
    </message>
    <message>
        <source>ON</source>
        <translation>オン</translation>
    </message>
    <message>
        <source>OFF</source>
        <translation>オフ</translation>
    </message>
    <message>
        <source>Global keyboard shortcuts</source>
        <translation>共通キーボードショートカット</translation>
    </message>
    <message>
        <source>Assigned shortcut keys.</source>
        <translation>割り当てられたショートカットキー</translation>
    </message>
    <message>
        <source>Keyboard shortcut not assigned or assigned more than once.</source>
        <translation>一度割り当てられたキーを他のショートカットに割り当てることはできません。</translation>
    </message>
    <message>
        <source>If it shows assigned but does not work, it is being used by another program.</source>
        <translation>もし、割り当てられたように見えるのに動作しない場合は、他のプログラムによって使用されている可能性があります。</translation>
    </message>
    <message>
        <source>Snapshot</source>
        <translation>スナップショット</translation>
    </message>
    <message>
        <source>Imagepath</source>
        <translation>画像のパス</translation>
    </message>
    <message>
        <source>Hide this window</source>
        <translation>このウィンドウを隠す</translation>
    </message>
    <message>
        <source>Seconds wait before recording</source>
        <translation>記録開始までの待機秒数</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>ウィンドウ</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>全画面</translation>
    </message>
</context>
<context>
    <name>formMainWindow_wl</name>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>画像の著作権およびライセンス</translation>
    </message>
    <message>
        <source>Create images of tabs </source>
        <translation>タブのイメージを作成</translation>
    </message>
    <message>
        <source>License information</source>
        <translation>ライセンス情報</translation>
    </message>
    <message>
        <source>ON</source>
        <translation>オン</translation>
    </message>
    <message>
        <source>OFF</source>
        <translation>オフ</translation>
    </message>
    <message>
        <source>Record Time:</source>
        <translation>録画時間:</translation>
    </message>
    <message>
        <source>Video size:</source>
        <translation>動画サイズ</translation>
    </message>
    <message>
        <source>Free disk space:</source>
        <translation>空きディスク領域:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>情報</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>ウィンドウ</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>全画面</translation>
    </message>
    <message>
        <source>Area</source>
        <translation>範囲</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>動画コーデック</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>フレーム</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>形式</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>利用可能</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>利用不可</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>開始</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>停止</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>フォルダー</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>マウスカーソルを録画しない</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>音声コーデック</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>ビデオ保存パス</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>カウントダウン</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>ヘルプ</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>ネガポジ反転</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>グレー</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>白黒</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>カメラ</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>垂直反転</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>水平反転</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>ウィンドウ枠非表示</translation>
    </message>
    <message>
        <source>Second wait before recording</source>
        <translation>録画前の秒数</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>リセット</translation>
    </message>
    <message>
        <source>Hide this window</source>
        <translation>このウィンドウを隠す</translation>
    </message>
    <message>
        <source>Seconds wait before recording</source>
        <translation>記録開始までの待機秒数</translation>
    </message>
</context>
<context>
    <name>license</name>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>画像の著作権およびライセンス</translation>
    </message>
</context>
<context>
    <name>playerGST</name>
    <message>
        <source>Play</source>
        <translation>再生</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>一時停止</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>停止</translation>
    </message>
</context>
</TS>